# Funktion zur Herleitung der Gesamtnek nach NEK2023
#' Herleitung der NEK nach der NEK-Methode Version 2023
#'
#' Mit der NEK werden Standorte hinsichtlich ihrer landwirtschaftlichen Nutzungseignung beurteilt.
#' Dabei werden Boden, Klima und Terrain berücksichtigt.
#' Dieses Beurteilungsschema wurde hier publiziert:
#'
#' Greiner, L.; Petter, G.; Keller, A. (2023): Anleitung zur Beurteilung der
#' landwirtschaftlichen Nutzungseignung. Methode der Nutzungseignungsklassen (NEK-Methode).
#' Aktualisierte Version 2023. Kompetenzzentrum Boden KOBO. BFH-HAFL.
#'
#'
#' Die hier vorliegende Beurteilung basiert
#' auf den Bewertungstabellen der NEK-2023 Stand 24.10.2023
#'
#'
#' @param alle_neks Form von alle_neks: alle_neks  <- data.frame(nek_whg2023, nek_skelett2023, nek_textur2023, nek_humus2023, nek_ph2023, nek_terrain2023, nek_spezialfaelle2023). Vorhanden sein müssen: nek_whg2023, nek_skelett2023, nek_textur2023, nek_humus2023,nek_ph2023, nek_terrain2023. Eine "nek_spezialfaelle2023" kann vorhanden sein oder auch nicht
#' @return Die finale NEK-2023
#' @export





gesamtnek_2023<-function (alle_neks)
{

  # Bewertungen finden
  bewertung <-!is.na(alle_neks)

  # Regel A testen
  Avorhanden<-rowSums(bewertung[,1:5])

  # Namen der Sub-NEKS
  namen_neks <- colnames(alle_neks)

  # Gesamtbewertung anwenden
  anz_p <- nrow(alle_neks)

  nek_2023  <- array(NaN,dim=c(anz_p,1))
  limitierung <- array(NaN,dim=c(anz_p,1))


  for (i in 1:anz_p){
    if (Avorhanden[i]>=5){
      schlechteste_nek <- max(alle_neks[i,],na.rm=TRUE)
      nek_2023[i]    <- schlechteste_nek

      index_name    <- which(alle_neks[i,]==schlechteste_nek)
      limit_temp    <- namen_neks[index_name]
      limitierung[i]<- paste0(limit_temp,sep = "",collapse = ", ")
    }
  }

  resultate <- data.frame(nek_2023,limitierung)
  return(resultate)


}
