#' Herleitung der Humuslimitierung nach der NEK-Methode Version 2023
#'
#' Mit der NEK werden Standorte hinsichtlich ihrer landwirtschaftlichen Nutzungseignung beurteilt.
#' Dabei werden Boden, Klima und Terrain berücksichtigt.
#' Dieses Beurteilungsschema wurde hier publiziert:
#'
#' Greiner, L.; Petter, G.; Keller, A. (2023): Anleitung zur Beurteilung der
#' landwirtschaftlichen Nutzungseignung. Methode der Nutzungseignungsklassen (NEK-Methode).
#' Aktualisierte Version 2023. Kompetenzzentrum Boden KOBO. BFH-HAFL.
#'
#'
#' Die hier vorliegende Beurteilung basiert
#' auf den Bewertungstabellen der NEK-2023 Stand 24.10.2023
#'
#'
#'
#' @param ob_humus Humusgehalt im Oberboden (% der Feinerde)
#' @param ub_humus Humusgehalt im Unterboden (% der Feinerde)
#' @param klimalim Klimatische Limitierung hergeleitet aus den Klimaeignungszonen
#' @param bewertungstab Bewertungstabelle mit der Zuordung des Humusgehalts zu einer NEK nach der klimatischer Limitierung unterteilt
#' @return Die NEK, welche aus der Limitierung durch den Humusgehalt und das Klima ergibt
#' @export

nek_humus<- function(ob_humus, ub_humus, klimalim, bewertungstab){

  anz_profile<-length(klimalim)
  startspalte_nek <- 5


  index_humus <- array(NaN,dim=c(anz_profile,1))
  for(i in 1:anz_profile){
    if(!is.nan(ob_humus[i]) & !is.nan(ub_humus[i])){
      index_humus_temp <- which(ob_humus[i]>=bewertungstab[,1] &
                                  ob_humus[i]<=bewertungstab[,2]&
                                  ub_humus[i]>=bewertungstab[,3] &
                                  ub_humus[i]<=bewertungstab[,4])

      index_col <- klimalim[i] + startspalte_nek-1

      if (!is.na(klimalim[i]) & klimalim[i]<=4){
        common_index <- index_humus_temp

        if (length(common_index)>0){
          Bewertungen=bewertungstab[common_index, index_col]
          index_humus[i]=common_index[min(which(Bewertungen==min(Bewertungen)))]
        }
      }
    }
  }

  # NEK zuordnen
  nek_humus     <- array(NaN,dim=c(anz_profile,1))


  for(i in 1:anz_profile){
    if (!is.na(klimalim[i]) & klimalim[i]<=4){
      index_col <- klimalim[i] + startspalte_nek-1
    } else {
      index_col <- NaN
    }
    if (!is.nan(index_col) & !is.nan(index_humus[i])){
      nek_humus[i] <- bewertungstab[[index_humus[i], index_col]] }
  }

  rm(index_col)

  return(nek_humus)


}
