#' Herleitung der pH-limitierung nach der NEK-Methode Version 2023
#'
#' Mit der NEK werden Standorte hinsichtlich ihrer landwirtschaftlichen Nutzungseignung beurteilt.
#' Dabei werden Boden, Klima und Terrain berücksichtigt.
#' Dieses Beurteilungsschema wurde hier publiziert:
#'
#' Greiner, L.; Petter, G.; Keller, A. (2023): Anleitung zur Beurteilung der
#' landwirtschaftlichen Nutzungseignung. Methode der Nutzungseignungsklassen (NEK-Methode).
#' Aktualisierte Version 2023. Kompetenzzentrum Boden KOBO. BFH-HAFL.
#'
#'
#' Die hier vorliegende Beurteilung basiert
#' auf den Bewertungstabellen der NEK-2023 Stand 24.10.2023
#'
#'
#'
#' @param ub_ph pH im Unterboden
#' @param klimalim Klimatische Limitierung hergeleitet aus den Klimaeignungszonen
#' @param bewertungstab Bewertungstabelle mit der Zurordung des Unterboden-pH zu einer NEK nach der klimatischer Limitierung unterteilt
#' @return Die NEK, welche aus der Limitierung durch den pH und das Klima ergibt
#' @export


nek_ph<- function(ub_ph,klimalim, bewertungstab){

  anz_profile     <-length(klimalim)
  startspalte_nek <- 3



# Findet pH-Bereich von Profil in Bewertungstabelle pH
index_ph <- array(NaN,dim=c(anz_profile,1))

for(i in 1:anz_profile){
  if(!is.nan(ub_ph[i]) & ub_ph[i]>=0){
    index_ph_temp <- which(ub_ph[i]>=bewertungstab[,1] &
                             ub_ph[i]<=bewertungstab[,2])

    index_col <- klimalim[i] + startspalte_nek-1
    if (!is.na(klimalim[i]) & klimalim[i]<=4){
      common_index <- index_ph_temp

      if (length(common_index)>0){
        Bewertungen=bewertungstab[common_index, index_col]
        index_ph[i]=common_index[min(which(Bewertungen==min(Bewertungen)))]
      }
    }
  }
}

# NEK entsprechend pH zuordnen
nek_pH          <- array(NaN,dim=c(anz_profile,1))

for(i in 1:anz_profile){
  if (!is.na(klimalim[i]) & klimalim[i]<=4){
    index_col <- klimalim[i] + startspalte_nek-1
  } else {
    index_col <- NaN
  }
  if (!is.nan(index_col) & !is.nan(index_ph[i])){
    nek_pH[i] <- bewertungstab[[index_ph[i], index_col]] }
  rm(index_col)
}

return(nek_pH)


}
