#' Herleitung der Terrainlimitierung nach der NEK-Methode Version 2023
#'
#' Mit der NEK werden Standorte hinsichtlich ihrer landwirtschaftlichen Nutzungseignung beurteilt.
#' Dabei werden Boden, Klima und Terrain berücksichtigt.
#' Dieses Beurteilungsschema wurde hier publiziert:
#'
#' Greiner, L.; Petter, G.; Keller, A. (2023): Anleitung zur Beurteilung der
#' landwirtschaftlichen Nutzungseignung. Methode der Nutzungseignungsklassen (NEK-Methode).
#' Aktualisierte Version 2023. Kompetenzzentrum Boden KOBO. BFH-HAFL.
#'
#'
#' Die hier vorliegende Beurteilung basiert
#' auf den Bewertungstabellen der NEK-2023 Stand 24.10.2023
#'
#'
#'
#' @param hangneigung Hangneigung
#' @param neigungsart_unregelmaessig ungleichmässige Neigungsart handelt (1) oder nicht (0), abgeleitet aus der Geländeform nach FAL24
#' @param klimalim Klimatische Limitierung hergeleitet aus den Klimaeignungszonen
#' @param bewertungstab Bewertungstabelle mit der Zurordung des Terrains zu einer NEK nach der klimatischer Limitierung unterteilt
#' @return Die NEK, welche aus der Limitierung durch das Terrain und das Klima ergibt
#' @export


nek_terrain<- function(hangneigung,neigungsart_unregelmaessig, klimalim, bewertungstab){

  anz_profile     <-length(klimalim)
  startspalte_nek <- 4



  # Findet Terrain-Bereich von Profil in Bewertungstabelle---------
  index_hangneigung <- array(NaN,dim=c(anz_profile,1))

for(i in 1:anz_profile){
  if(!is.nan(hangneigung[i]) & hangneigung[i]!= "-"){
    index_hangneigung_temp     <- which(hangneigung[i]>=bewertungstab[,1] &
                                  hangneigung[i]<=bewertungstab[,2])
    index_neigungsart_temp <- which(neigungsart_unregelmaessig[i] == bewertungstab[,3])

    index_col <- klimalim[i] + startspalte_nek-1
    if (!is.na(klimalim[i]) & klimalim[i]<=4){
      common_index <- Reduce(intersect, list(index_hangneigung_temp,index_neigungsart_temp))

      if (length(common_index)>0){
        Bewertungen=bewertungstab[common_index, index_col]
        index_hangneigung[i]=common_index[min(which(Bewertungen==min(Bewertungen)))]
      }
    }
  }
}

# NEK entsprechend der Geländeform zuordnen
nek_terrain     <- array(NaN,dim=c(anz_profile,1))

for(i in 1:anz_profile){
  if (!is.na(klimalim[i]) & klimalim[i]<=4){
    index_col <- klimalim[i] + startspalte_nek-1
  } else {
    index_col <- NaN
  }
  if (!is.nan(index_col) & !is.nan(index_hangneigung[i])){
    nek_terrain[i] <- bewertungstab[[index_hangneigung[i], index_col]] }
  rm(index_col)
}

return(nek_terrain)

}
