#' Funktion: Nutzungsgebietzuordnung
#' Jede Klimaeignungszone wird einer klimatischen Limitierung zugeordnet
#' 
#' Input: klimaeignungszone (nach Jeanneret und Vautier 1977, in Zahlenform)
#' 
#' Output:
#' 1: keine Limitierung: A2, A3, B2, B3
#' 2: leichte Limitierung: A4, B4, C1-4
#' 3: mittlere Limitierung: A5, B5, C5-6, D1-4
#' 4: starke Limitierung: D5-6, E1-3, E4-6, F
#' 7: nicht beurteilbar in NEK-Methode 2023
#' relevant für Bewertung: 1-4. nicht relevant, aber eigentlich 3 oder 4: hier 7
#'
#' @param klimaeignungszone Klimaeignungsklasse
#' @param nutzungsgebietzuordnung Zuordnungtabelle der Klimaeignungszonen zur klimatischen Limitierung
#' @return klimatische_limitierung
#' @export
#'

ng_aus_klimaek<- function (klimaeignungszone, nutzungsgebietzuordnung)
{
  
  anz_p <- length(klimaeignungszone)
  
  ## Nutzungsgebiet finden
  index_ng <- array(NaN,dim=c(anz_p,1))
  for (i in 1:anz_p){
    if (!is.nan(klimaeignungszone[i])){
      index_ng[i] <- min(which(klimaeignungszone[i] == nutzungsgebietzuordnung$Klimaeignungsklassen_zahl))
    }
  }
  
  
  klimatische_limitierung<- nutzungsgebietzuordnung$Nutzungsgebiet[index_ng]
  
  return(klimatische_limitierung)
  
  
}

